==> vdocipher_flutter-2.2.0.tar.gz: lib/src/offline/download_options.dart <==
import 'dart:collection';

import 'package:vdocipher_flutter/src/offline/internal_download_option.dart';
import 'package:vdocipher_flutter/src/types/types.dart';

/// Includes media information and download options for audio and video tracks
class DownloadOptions {
  String? mediaId;
  MediaInfo mediaInfo;
  List<AudioTrack> allAudio;
  List<VideoTrack> allVideo;

  DownloadOptions(this.mediaId, this.mediaInfo, this.allAudio, this.allVideo);

  static DownloadOptions fromMap(Map<Object?, Object?> downloadOptionsMap,
      String otp, String playbackInfo, String? customPlayerId) {
    String mediaId = downloadOptionsMap['mediaId'] as String;

    Map<Object?, Object?> mediaInfoMap =
        downloadOptionsMap['mediaInfo'] as Map<Object?, Object?>;

    MediaInfo mediaInfo = MediaInfo(
        mediaId: mediaInfoMap['mediaId'] as String,
        type: MediaInfoType.offline,
        title: mediaInfoMap['title'] as String,
        description: mediaInfoMap['description'] as String,
        duration: Duration(milliseconds: mediaInfoMap['duration'] as int));

    final List<AudioTrack> allAudio = [];
    final List<VideoTrack> allVideo = [];

    List availableTracks = downloadOptionsMap["availableTracks"] as List;

    availableTracks.forEach((element) {
      if (element is Map) {
        switch (element["type"]) {
          case "audio":
            allAudio.add(AudioTrack(
                id: element["id"],
                language: element["language"],
                bitrate: element["bitrate"]));
            break;
          case "video":
            allVideo.add(VideoTrack(
                id: element["id"],
                bitrate: element["bitrate"],
                width: element["width"],
                height: element["height"]));
            break;
        }
      }
    });

    return InternalDownloadOption(mediaId, mediaInfo, allAudio, allVideo, otp,
        playbackInfo, customPlayerId);
  }

  static Map<String, Object?> toMap(DownloadOptions downloadOptions) {
    Map<String, Object?> downloadOptionsMap = HashMap();
    InternalDownloadOption internalDownloadOption =
        downloadOptions as InternalDownloadOption;
    downloadOptionsMap["mediaId"] = downloadOptions.mediaId;
    downloadOptionsMap["mediaInfo"] = _mediaInfoMap(downloadOptions.mediaInfo);
    downloadOptionsMap["allVideo"] =
        _videoTrackMapList(downloadOptions.allVideo);
    downloadOptionsMap["allAudio"] =
        _audioTrackMapList(downloadOptions.allAudio);
    downloadOptionsMap["otp"] = internalDownloadOption.otp;
    downloadOptionsMap["playbackInfo"] = internalDownloadOption.playbackInfo;
    downloadOptionsMap["customPlayerId"] =
        internalDownloadOption.customPlayerId;

    return downloadOptionsMap;
  }

  static HashMap<String, Object> _mediaInfoMap(MediaInfo mediaInfo) {
    HashMap<String, Object> mediaInfoMap = HashMap();
    mediaInfoMap["mediaId"] = mediaInfo.mediaId;
    mediaInfoMap["type"] = mediaInfo.type.toString();
    mediaInfoMap["title"] =
        (mediaInfo.title != null ? mediaInfo.title : null) as Object;
    mediaInfoMap["description"] = (mediaInfo.description != null
        ? mediaInfo.description
        : null) as Object;
    mediaInfoMap["duration"] = mediaInfo.duration.inMilliseconds;
    return mediaInfoMap;
  }

  static List<Map<String, Object?>> _videoTrackMapList(
      List<VideoTrack> tracks) {
    List<Map<String, Object?>> trackList = List.empty(growable: true);
    for (VideoTrack track in tracks) {
      trackList.add(_videoTrackMap(track));
    }
    return trackList;
  }

  static List<Map<String, Object?>> _audioTrackMapList(
      List<AudioTrack> tracks) {
    List<Map<String, Object?>> trackList = List.empty(growable: true);
    for (AudioTrack track in tracks) {
      trackList.add(_audioTrackMap(track));
    }
    return trackList;
  }

  static Map<String, Object?> _audioTrackMap(AudioTrack audioTrack) {
    Map<String, Object?> trackMap = HashMap();
    trackMap["id"] = audioTrack.id;
    trackMap["type"] = "audio";
    trackMap["language"] = audioTrack.language;
    trackMap["bitrate"] = audioTrack.bitrate;

    return trackMap;
  }

  static Map<String, Object?> _videoTrackMap(VideoTrack videoTrack) {
    Map<String, Object?> trackMap = HashMap();
    trackMap["id"] = videoTrack.id;
    trackMap["type"] = "video";
    trackMap["width"] = videoTrack.width;
    trackMap["height"] = videoTrack.height;
    trackMap["bitrate"] = videoTrack.bitrate;

    return trackMap;
  }
}

==> vdocipher_flutter-2.2.7.tar.gz: lib/src/offline/download_options.dart <==
import 'dart:collection';

import 'package:vdocipher_flutter/src/offline/internal_download_option.dart';
import 'package:vdocipher_flutter/src/types/types.dart';

/// Includes media information and download options for audio and video tracks
class DownloadOptions {
  String? mediaId;
  MediaInfo mediaInfo;
  List<AudioTrack> allAudio;
  List<VideoTrack> allVideo;

  DownloadOptions(this.mediaId, this.mediaInfo, this.allAudio, this.allVideo);

  static DownloadOptions fromMap(Map<Object?, Object?> downloadOptionsMap,
      String otp, String playbackInfo, String? customPlayerId) {
    String mediaId = downloadOptionsMap['mediaId'] as String;

    Map<Object?, Object?> mediaInfoMap =
        downloadOptionsMap['mediaInfo'] as Map<Object?, Object?>;

    MediaInfo mediaInfo = MediaInfo(
        mediaId: mediaInfoMap['mediaId'] as String,
        type: MediaInfoType.offline,
        title: mediaInfoMap['title'] as String,
        description: mediaInfoMap['description'] as String,
        duration: Duration(milliseconds: mediaInfoMap['duration'] as int));

    final List<AudioTrack> allAudio = [];
    final List<VideoTrack> allVideo = [];

    List availableTracks = downloadOptionsMap["availableTracks"] as List;

    for (var element in availableTracks) {
      if (element is Map) {
        switch (element["type"]) {
          case "audio":
            allAudio.add(AudioTrack(
                id: element["id"],
                language: element["language"],
                bitrate: element["bitrate"]));
            break;
          case "video":
            allVideo.add(VideoTrack(
                id: element["id"],
                bitrate: element["bitrate"],
                width: element["width"],
                height: element["height"]));
            break;
        }
      }
    }

    return InternalDownloadOption(mediaId, mediaInfo, allAudio, allVideo, otp,
        playbackInfo, customPlayerId);
  }

  static Map<String, Object?> toMap(DownloadOptions downloadOptions) {
    Map<String, Object?> downloadOptionsMap = HashMap();
    InternalDownloadOption internalDownloadOption =
        downloadOptions as InternalDownloadOption;
    downloadOptionsMap["mediaId"] = downloadOptions.mediaId;
    downloadOptionsMap["mediaInfo"] = _mediaInfoMap(downloadOptions.mediaInfo);
    downloadOptionsMap["allVideo"] =
        _videoTrackMapList(downloadOptions.allVideo);
    downloadOptionsMap["allAudio"] =
        _audioTrackMapList(downloadOptions.allAudio);
    downloadOptionsMap["otp"] = internalDownloadOption.otp;
    downloadOptionsMap["playbackInfo"] = internalDownloadOption.playbackInfo;
    downloadOptionsMap["customPlayerId"] =
        internalDownloadOption.customPlayerId;

    return downloadOptionsMap;
  }

  static HashMap<String, Object> _mediaInfoMap(MediaInfo mediaInfo) {
    HashMap<String, Object> mediaInfoMap = HashMap();
    mediaInfoMap["mediaId"] = mediaInfo.mediaId;
    mediaInfoMap["type"] = mediaInfo.type.toString();
    mediaInfoMap["title"] = mediaInfo.title as Object;
    mediaInfoMap["description"] = mediaInfo.description as Object;
    mediaInfoMap["duration"] = mediaInfo.duration.inMilliseconds;
    return mediaInfoMap;
  }

  static List<Map<String, Object?>> _videoTrackMapList(
      List<VideoTrack> tracks) {
    List<Map<String, Object?>> trackList = List.empty(growable: true);
    for (VideoTrack track in tracks) {
      trackList.add(_videoTrackMap(track));
    }
    return trackList;
  }

  static List<Map<String, Object?>> _audioTrackMapList(
      List<AudioTrack> tracks) {
    List<Map<String, Object?>> trackList = List.empty(growable: true);
    for (AudioTrack track in tracks) {
      trackList.add(_audioTrackMap(track));
    }
    return trackList;
  }

  static Map<String, Object?> _audioTrackMap(AudioTrack audioTrack) {
    Map<String, Object?> trackMap = HashMap();
    trackMap["id"] = audioTrack.id;
    trackMap["type"] = "audio";
    trackMap["language"] = audioTrack.language;
    trackMap["bitrate"] = audioTrack.bitrate;

    return trackMap;
  }

  static Map<String, Object?> _videoTrackMap(VideoTrack videoTrack) {
    Map<String, Object?> trackMap = HashMap();
    trackMap["id"] = videoTrack.id;
    trackMap["type"] = "video";
    trackMap["width"] = videoTrack.width;
    trackMap["height"] = videoTrack.height;
    trackMap["bitrate"] = videoTrack.bitrate;

    return trackMap;
  }
}
